/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the  Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * version 3 along with this program.  If not, see
 * <http://www.gnu.org/licenses/>
 *
 * Authored by: Sam Spilsbury <sam.spilsbury@canonical.com>
 *
 */
#ifndef _UNITY_MOCK_SWITCHER_VIEW_H
#define _UNITY_MOCK_SWITCHER_VIEW_H

#include <gtest/gtest.h>
#include <gmock/gmock.h>

#include <memory>

#include <SwitcherView.h>
#include <AbstractLauncherIcon.h>

namespace unity
{
namespace switcher
{
class MockSwitcherView :
  public View::Impl
{
  public:

    MOCK_METHOD0(ExternalTargets, ui::LayoutWindow::Vector ());
    MOCK_METHOD1(SetModel, void (SwitcherModel::Ptr));
    MOCK_METHOD0(GetModel, SwitcherModel::Ptr ());
    MOCK_METHOD3(ConnectToMouseEvents,
                 View::MouseEventConnections (const View::MouseButtonCallback &mouse_down_callback,
                                              const View::MouseButtonCallback &mouse_up_callback,
                                              const View::MouseDragCallback   &mouse_drag_callback));
    MOCK_METHOD0(QueueDraw, void ());
    MOCK_CONST_METHOD0(GetAbsoluteGeometry, nux::Geometry ());
    MOCK_METHOD2(IconIndexAt, int (int, int));
    MOCK_METHOD1(SetBackgroundColor, void(nux::Color const&));
    MOCK_METHOD1(SetupBackground, void(bool));

    MOCK_METHOD1(SetMonitor, void(unsigned int));
    MOCK_METHOD1(SetBorderSize, void(unsigned int));
    MOCK_METHOD1(SetFlatSpacing, void(int));
    MOCK_METHOD1(SetTextSize, void(unsigned int));
    MOCK_METHOD1(SetTileSize, void(unsigned int));
    MOCK_METHOD1(SetIconSize, void(unsigned int));
    MOCK_METHOD1(SetAnimationLength, void(unsigned int));
    MOCK_METHOD1(SetRenderBoxes, void(bool));

    MOCK_METHOD0(GetBorderSize, unsigned int());
    MOCK_METHOD0(GetFlatSpacing, unsigned int());
    MOCK_METHOD0(GetTextSize, unsigned int());
    MOCK_METHOD0(GetIconSize, unsigned int());
    MOCK_METHOD0(GetTileSize, unsigned int());
    MOCK_METHOD0(GetAnimationLength, unsigned int());
};
}
}

#endif
